#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module MpqrAccept
            class InstitutionConfiguration < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'f104cf94-df39-4d88-b76e-d2584687c06c' => OperationConfig.new("/mpqr-accept/v1/api/bank/configuration", "query", [], []),
                    '52ad8869-0bcb-4262-8a6c-9524fe47270d' => OperationConfig.new("/mpqr-accept/v1/api/bank/configuration/publish", "update", [], []),
                    '805e8fab-a267-46e9-95fc-b616d3f56a0c' => OperationConfig.new("/mpqr-accept/v1/api/bank/configuration", "update", [], []),
                    '709c781e-f76e-421a-8ce4-6e09c09ef8ea' => OperationConfig.new("/mpqr-accept/v1/api/bank/configuration/terminate", "update", [], []),
                    'c5c16024-841a-4379-acdd-1ee475cc8231' => OperationConfig.new("/mpqr-accept/v1/api/bank/configuration/unpublish", "update", [], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public







                def self.read(criteria)
                    #
                    #Query objects of type InstitutionConfiguration by id and optional criteria
                    #@param [Dict] criteria
                    #@return [InstitutionConfiguration] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("f104cf94-df39-4d88-b76e-d2584687c06c",InstitutionConfiguration.new(criteria))
                end



                def publish
                    #
                    #Updates an object of type InstitutionConfiguration
                    #
                    #@return [InstitutionConfiguration] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("52ad8869-0bcb-4262-8a6c-9524fe47270d",self)
                end








                def update
                    #
                    #Updates an object of type InstitutionConfiguration
                    #
                    #@return [InstitutionConfiguration] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("805e8fab-a267-46e9-95fc-b616d3f56a0c",self)
                end








                def terminate
                    #
                    #Updates an object of type InstitutionConfiguration
                    #
                    #@return [InstitutionConfiguration] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("709c781e-f76e-421a-8ce4-6e09c09ef8ea",self)
                end








                def unpublish
                    #
                    #Updates an object of type InstitutionConfiguration
                    #
                    #@return [InstitutionConfiguration] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("c5c16024-841a-4379-acdd-1ee475cc8231",self)
                end







            end
        end
    end
end







